@@ -60,6 +60,7 @@ class TestImage(ClientTestCase):
                         "name": "myimage",
                         "product_id": "p1",
                         "geometry": self.geometry,
+                        "c6s_dlsr": [],
                     },
                     "type": "image",
                     "id": "p1:myimage",
@@ -132,8 +133,8 @@ class TestImage(ClientTestCase):
         assert (
             datetime.datetime.strptime(
                 "2019-08-20T08:08:16.123456Z", "%Y-%m-%dT%H:%M:%S.%fZ"
-            ).replace(tzinfo=utc) ==
-            i.acquired
+            ).replace(tzinfo=utc)
+            == i.acquired
         )
 
     def test_search_intersects(self):
@@ -675,8 +676,8 @@ class TestImage(ClientTestCase):
         assert (
             self.get_request_body(2)["data"]["attributes"]["image_upload_options"][
                 "upload_size"
-            ] ==
-            200
+            ]
+            == 200
         )
 
         upload.wait_for_completion(15)
