@@ -1,6 +1,8 @@
 from .syntax import (
     PRIMITIVE_TYPES,
+    RESERVED_WORDS,
     is_key,
+    is_guid_key,
     is_literal,
     is_quoted_json,
     is_application,
@@ -12,7 +14,9 @@ from .syntax import (
 
 __all__ = [
     "PRIMITIVE_TYPES",
+    "RESERVED_WORDS",
     "is_key",
+    "is_guid_key",
     "is_literal",
     "is_quoted_json",
     "is_application",
