@@ -1,12 +1,7 @@
 import six
 import numbers
 
-
-try:
-    # only after py3.4
-    from collections import abc
-except ImportError:
-    import collections as abc
+from collections import abc
 
 
 PRIMITIVE_TYPES = six.string_types + (numbers.Number, bool, type(None))
@@ -60,7 +55,11 @@ def is_named_application_part(part):
 
 
 def is_params(expr):
-    return is_nonstring_sequence(expr) and all(is_key(name) for name in expr)
+    return (
+        is_nonstring_sequence(expr)
+        and all(is_key(name) for name in expr)
+        and len(set(expr)) == len(expr)
+    )
 
 
 def is_graft(expr):
