@@ -1,4 +1,4 @@
-# Copyright 2018-2019 Descartes Labs.
+# Copyright 2018-2020 Descartes Labs.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -216,7 +216,7 @@ class Scene(object):
 
         Raises
         ------
-        `NotFoundError`
+        NotFoundError
             If the ``scene_id`` cannot be found in the Descartes Labs catalog
         """
 
@@ -388,11 +388,10 @@ class Scene(object):
             Whether to mask out values in each band that equal
             that band's ``nodata`` sentinel value.
         mask_alpha : bool or str or None, default None
-            Whether to mask pixels in all bands where the alpha band of all scenes is 0.
+            Whether to mask pixels in all bands where the alpha band of the scene is 0.
             Provide a string to use an alternate band name for masking.
-            If the alpha band is available for all scenes in the collection and
-            ``mask_alpha`` is None, ``mask_alpha`` is set to True. If not,
-            mask_alpha is set to False.
+            If the alpha band is available and ``mask_alpha`` is None, ``mask_alpha``
+            is set to True. If not, mask_alpha is set to False.
         bands_axis : int, default 0
             Axis along which bands should be located in the returned array.
             If 0, the array will have shape ``(band, y, x)``, if -1,
@@ -455,9 +454,9 @@ class Scene(object):
             If requested bands are unavailable.
             If band names are not given or are invalid.
             If the requested bands have incompatible dtypes.
-        `NotFoundError`
+        NotFoundError
             If a Scene's ID cannot be found in the Descartes Labs catalog
-        `BadRequestError`
+        BadRequestError
             If the Descartes Labs platform is given invalid parameters
         """
         if raster_client is None:
@@ -519,6 +518,7 @@ class Scene(object):
 
         try:
             arr, info = raster_client.ndarray(**full_raster_args)
+
         except NotFoundError:
             six.raise_from(
                 NotFoundError(
@@ -548,19 +548,9 @@ class Scene(object):
                 if drop_alpha:
                     arr = arr[:-1]
                     bands.pop(-1)
-
-            mask = np.zeros_like(arr, dtype=bool)
-
-            if mask_nodata:
-                for i, bandname in enumerate(bands):
-                    nodata = self_bands[bandname].get("nodata")
-                    if nodata is not None:
-                        mask[i] = arr[i] == nodata
-
-            if mask_alpha:
-                mask |= alpha == 0
-
-            arr = np.ma.MaskedArray(arr, mask, copy=False)
+                arr.mask = ~alpha.astype(bool)
+        else:
+            arr = arr.data
 
         if bands_axis != 0:
             arr = np.moveaxis(arr, 0, bands_axis)
@@ -667,9 +657,9 @@ class Scene(object):
             If band names are not given or are invalid.
             If the requested bands have incompatible dtypes.
             If ``format`` is invalid, or the path has an invalid extension.
-        `NotFoundError`
+        NotFoundError
             If a Scene's ID cannot be found in the Descartes Labs catalog
-        `BadRequestError`
+        BadRequestError
             If the Descartes Labs platform is given invalid parameters
         """
         bands = self._bands_to_list(bands)
