@@ -1,23 +1,27 @@
 from .exceptions import JobComputeError, JobTimeoutError
-from .workflow import Workflow
+from .visualization import VizOption
+from .workflow import Workflow, wmts_url
 from .versionedgraft import VersionedGraft
 from .job import Job
-from .xyz import XYZ, XYZErrorListener
+from .xyz import XYZ, XYZLogListener
 from .toplevel import compute, publish, use
 
 __all__ = [
     # .exceptions
     "JobComputeError",
     "JobTimeoutError",
+    # .visualization
+    "VizOption",
     # .workflow
     "Workflow",
+    "wmts_url",
     # .versionedgraft
     "VersionedGraft",
     # .job
     "Job",
     # .xyz
     "XYZ",
-    "XYZErrorListener",
+    "XYZLogListener",
     # .toplevel
     "compute",
     "publish",
