@@ -1,22 +1,32 @@
+from .concat import concat
+from .convolution import Kernel, conv2d
 from .feature import Feature
 from .featurecollection import FeatureCollection
-from .load_geojson import load_geojson, load_geojson_file
-from .geometry import Geometry, GeometryCollection
 from .geocontext import GeoContext
+from .geometry import Geometry
+from .geometrycollection import GeometryCollection
 from .groupby import ImageCollectionGroupby
 from .image import Image
 from .imagecollection import ImageCollection
+from .load_geojson import load_geojson, load_geojson_file
 
+# from .pca import PCA
+from .where import where
 
 __all__ = [
+    "concat",
+    "Kernel",
+    "conv2d",
     "Feature",
     "FeatureCollection",
-    "load_geojson",
-    "load_geojson_file",
+    "GeoContext",
     "Geometry",
     "GeometryCollection",
-    "GeoContext",
+    "ImageCollectionGroupby",
     "Image",
     "ImageCollection",
-    "ImageCollectionGroupby",
+    "load_geojson",
+    "load_geojson_file",
+    #    "PCA",
+    "where",
 ]
