@@ -1,6 +1,5 @@
 import six
 
-from ... import env
 from collections import abc
 
 from ..containers import Dict, List, Tuple
@@ -222,8 +221,8 @@ class BandsMixin:
 
         self_type = type(self)
 
-        delayed_func = Function._delay(func, None, Str, self_type)
-        result_type = type(delayed_func)
+        delayed_func = Function.from_callable(func, Str, self_type)
+        result_type = delayed_func.return_type
         func = "wf.map_bands_imagery"
 
         if result_type not in (Image, ImageCollection):
@@ -286,4 +285,4 @@ class GeometryMixin:
         """
         from .image import Image
 
-        return Image._from_apply("wf.rasterize", self, value, env.geoctx)
+        return Image._from_apply("wf.rasterize", self, value)
