@@ -9,26 +9,26 @@ def parameter(name, type_):
     Useful for describing computations that will be further
     parameterized at runtime.
 
-    To actually provide values for the parameter at `Job` compute time,
-    pass them in as keyword arguments to `.compute`.
+    To actually provide values for the parameter at `.Job` compute time,
+    pass them in as keyword arguments to `~.models.compute` or `~.geospatial.Image.visualize`.
 
     Parameters
     ----------
     name: str
         Name of the parameter
-    type_: ProxyType
+    type_: Proxytype
         Type of the parameter
 
     Returns
     -------
-    proxyTime:
-        a ProxyType object of type `type_`.
+    parameter:
+        a Proxytype object of type ``type_``.
 
     Example
     -------
     >>> from descarteslabs.workflows import Float, parameter
     >>> my_program = Float(0.42) * parameter("scale", Float)
-    >>> my_program.compute(scale=wf.Float(0.99))  # doctest: +SKIP
+    >>> my_program.compute(scale=Float(0.99))  # doctest: +SKIP
     """
 
     if name.isdigit():
@@ -39,11 +39,13 @@ def parameter(name, type_):
             "Parameter type cannot be generic, must be concrete (like List[Int], not plain List)"
         )
 
-    return identifier(name, type_)
+    return type_._as_param(name)
 
 
 def identifier(name, type_):
     """
-    Create a Proxytype instance that references a graft key; i.e. for references to builtin constants or parameters.
+    Create a non-parameter Proxytype instance that references a graft key.
+    Internal method meant for references to builtin constants or parameters.
+    You shouldn't use this directly; consider `parameter` instead.
     """
     return type_._from_graft(graft_client.keyref_graft(name))
